@@ -3,13 +3,13 @@
 
 use anyhow::anyhow;
 use cid::Cid;
-use fvm_ipld_blockstore::Blockstore;
-use fvm_ipld_encoding::tuple::{Deserialize_tuple, Serialize_tuple};
-use fvm_ipld_encoding::Cbor;
 use fvm_shared::address::Address;
 use fvm_shared::bigint::{bigint_ser, Integer};
+use fvm_shared::blockstore::Blockstore;
 use fvm_shared::clock::ChainEpoch;
 use fvm_shared::econ::TokenAmount;
+use fvm_shared::encoding::tuple::*;
+use fvm_shared::encoding::Cbor;
 use indexmap::IndexMap;
 use num_traits::Zero;
 
@@ -112,10 +112,7 @@ impl State {
         curr_epoch: ChainEpoch,
     ) -> anyhow::Result<()> {
         if amount_to_spend < &0.into() {
-            return Err(anyhow!(
-                "amount to spend {} less than zero",
-                amount_to_spend
-            ));
+            return Err(anyhow!("amount to spend {} less than zero", amount_to_spend));
         }
         if &balance < amount_to_spend {
             return Err(anyhow!(
